Coverage for airflow.migrations.versions.13eb55f81627_for_compatibility: 75%

# Coverage for airflow.migrations.versions.13eb55f81627_for_compatibility : 75%

## 8 statements 6 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | """maintain history for compatibility with earlier migrations Revision ID: 13eb55f81627 Revises: 1507a7289a2f Create Date: 2015-08-23 05:12:49.732174 """ # revision identifiers, used by Alembic. revision = '13eb55f81627' down_revision = '1507a7289a2f' branch_labels = None depends_on = None def upgrade(): pass def downgrade(): pass